# Terminol

Terminol is a library that helps you create TUI programs. It is designed to be elegant and simple so much so you can probably finish your program even when you're drunk.[^1]

[^1]: Please do not file a bug report if your program doesn't work while you are drunk because terminol doesn't make you submit GitHub issues easier.
